@@ -1,11 +1,20 @@
 // Take a look at the license at the top of the repository in the LICENSE file.
 
+use std::{
+    cell::Cell,
+    sync::atomic::{AtomicBool, Ordering},
+};
+
+use crate::ffi;
 use glib::translate::*;
-use std::cell::Cell;
-use std::sync::atomic::{AtomicBool, Ordering};
+
+#[cfg(target_os = "macos")]
+extern "C" {
+    fn pthread_main_np() -> i32;
+}
 
 thread_local! {
-    static IS_MAIN_THREAD: Cell<bool> = Cell::new(false)
+    static IS_MAIN_THREAD: Cell<bool> = const{Cell::new(false)}
 }
 
 static INITIALIZED: AtomicBool = AtomicBool::new(false);
@@ -14,6 +23,8 @@ static INITIALIZED: AtomicBool = AtomicBool::new(false);
 /// Asserts that this is the main thread and `gtk::init` has been called.
 macro_rules! assert_initialized_main_thread {
     () => {
+        #[allow(unknown_lints)]
+        #[allow(clippy::if_then_panic)]
         if !crate::rt::is_initialized_main_thread() {
             if crate::rt::is_initialized() {
                 panic!("GTK may only be used from the main thread.");
@@ -33,9 +44,10 @@ macro_rules! skip_assert_initialized {
 #[allow(unused_macros)]
 macro_rules! assert_not_initialized {
     () => {
-        if crate::rt::is_initialized() {
-            panic!("This function has to be called before `gtk::init`.");
-        }
+        assert!(
+            !crate::rt::is_initialized(),
+            "This function has to be called before `gtk::init`."
+        );
     };
 }
 
@@ -43,17 +55,26 @@ macro_rules! assert_not_initialized {
 #[inline]
 pub fn is_initialized() -> bool {
     skip_assert_initialized!();
-    INITIALIZED.load(Ordering::Acquire)
+    if cfg!(not(feature = "unsafe-assume-initialized")) {
+        INITIALIZED.load(Ordering::Acquire)
+    } else {
+        true
+    }
 }
 
 /// Returns `true` if GTK has been initialized and this is the main thread.
 #[inline]
 pub fn is_initialized_main_thread() -> bool {
     skip_assert_initialized!();
-    IS_MAIN_THREAD.with(|c| c.get())
+    if cfg!(not(feature = "unsafe-assume-initialized")) {
+        IS_MAIN_THREAD.with(|c| c.get())
+    } else {
+        true
+    }
 }
 
-/// Informs this crate that GTK has been initialized and the current thread is the main one.
+/// Informs this crate that GTK has been initialized and the current thread is
+/// the main one.
 ///
 /// # Panics
 ///
@@ -67,6 +88,8 @@ pub fn is_initialized_main_thread() -> bool {
 /// 1. You have initialized the underlying GTK library yourself.
 /// 2. You did 1 on the thread with which you are calling this function
 /// 3. You ensure that this thread is the main thread for the process.
+#[allow(unknown_lints)]
+#[allow(clippy::if_then_panic)]
 pub unsafe fn set_initialized() {
     skip_assert_initialized!();
     if is_initialized_main_thread() {
@@ -76,6 +99,16 @@ pub unsafe fn set_initialized() {
     } else if !{ from_glib(ffi::gtk_is_initialized()) } {
         panic!("GTK was not actually initialized");
     }
+    //  OS X has its own notion of the main thread and init must be called on that
+    // thread.
+    #[cfg(target_os = "macos")]
+    {
+        assert_ne!(
+            pthread_main_np(),
+            0,
+            "Attempted to initialize GTK on OSX from non-main thread"
+        );
+    }
     INITIALIZED.store(true, Ordering::Release);
     IS_MAIN_THREAD.with(|c| c.set(true));
 }
@@ -92,13 +125,19 @@ pub unsafe fn set_initialized() {
 /// Instead, an Ok is returned if the windowing system was successfully
 /// initialized otherwise an Err is returned.
 #[doc(alias = "gtk_init")]
+#[allow(unknown_lints)]
+#[allow(clippy::if_then_panic)]
 pub fn init() -> Result<(), glib::BoolError> {
     skip_assert_initialized!();
     if is_initialized_main_thread() {
         return Ok(());
     } else if is_initialized() {
+        #[cfg(not(test))]
         panic!("Attempted to initialize GTK from two different threads.");
+        #[cfg(test)]
+        panic!("Use #[gtk::test] instead of #[test]");
     }
+
     unsafe {
         if from_glib(ffi::gtk_init_check()) {
             // See https://github.com/gtk-rs/gtk-rs-core/issues/186 for reasoning behind
@@ -124,13 +163,11 @@ pub fn init() -> Result<(), glib::BoolError> {
 
 #[cfg(test)]
 mod tests {
-    use crate::test_synced;
+    use crate as gtk4;
 
     #[test]
     fn init_should_acquire_default_main_context() {
-        test_synced(move || {
-            let context = glib::MainContext::ref_thread_default();
-            assert!(context.is_owner());
-        });
+        let context = glib::MainContext::ref_thread_default();
+        assert!(context.is_owner());
     }
 }
